==> baseui-8.3.0.tgz: package/esm/button-group/stateful-button-group.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
Copyright (c) 2018-2019 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import ButtonGroup from './button-group.js';
import StatefulContainer from './stateful-container.js';
export default function StatefulButtonGroup(props) {
  var children = props.children,
      initialState = props.initialState,
      restProps = _objectWithoutProperties(props, ["children", "initialState"]);

  return React.createElement(StatefulContainer, _extends({
    initialState: initialState
  }, restProps), function (_ref) {
    var containerProps = _extends({}, _ref);

    return React.createElement(ButtonGroup, containerProps, props.children);
  });
}

==> baseui-11.0.2.tgz: package/esm/button-group/stateful-button-group.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import ButtonGroup from './button-group.js';
import StatefulContainer from './stateful-container.js';
export default function StatefulButtonGroup(props) {
  var children = props.children,
      initialState = props.initialState,
      restProps = _objectWithoutProperties(props, ["children", "initialState"]);

  return /*#__PURE__*/React.createElement(StatefulContainer, _extends({
    initialState: initialState
  }, restProps), function (_ref) {
    var containerProps = _extends({}, _ref);

    return (
      /*#__PURE__*/
      //$FlowFixMe
      React.createElement(ButtonGroup, containerProps, props.children)
    );
  });
}
